@@ -33,11 +33,11 @@ from sepp.scripts.mailing_script import (
     send_failed_email,
     send_success_email,
 )
+from sepp.scripts.mock_soloplan import fake_soloplan_api
 from sepp.settings import (
     BASE_DIR,
     ERLEDIGT_ID,
     FAILED_ID,
-    fake_soloplan_s_n_c,
     ms_graph_config,  # Add msgraph import from settings
     soloplan_config,
 )
@@ -955,7 +955,7 @@ if __name__ == "__main__":
             )
             sys.exit(1)
     else:
-        soloplan = fake_soloplan_s_n_c()
+        soloplan = fake_soloplan_api()
         logger.info("Using mocked Soloplan API.")
 
     create_retries_csv()  # Create the CSV file for retries if it does not exist
